1.15.2 — Rucio 1.2 documentation

# 1.15.2

## General

### Features

- Documentation: Add REST API frontend using flask #586
- Traces: Include the number of accesses column in DID table to count dataset accesses #525

### Enhancements

- Documentation: Documentation overhaul for the workshop #572
- Documentation: Typo in the doc #799
- Functional tests: Configure slack notifications for travis #633
- Release management: setup.py and setup_rucio.py should be the same file #850

### Bugs

- Core & Internals: Postgres incompatibility #738
- Documentation: Spelling mistake in documentation #796
- Documentation: RSE_Expressions link broken in documentation #808
- Transfers: Protocol mismatch error in the conveyor #849

## Clients

### Enhancements

- Clients: Option to specify protocol implementation for upload #29
- Clients: Add Suggestions For MD5 Calculation #811
- Documentation: Improve doc for the CLI #551
- Release management: client dependencies update #754

### Bugs

- Clients: Flask imported in clients #800

## WebUI

### Enhancements

- Traces: webui: add tracing for webui downloads #665